# Authors

GSTools-Cython is available on [GitHub](https://github.com/GeoStat-Framework/GSTools-Cython)
and was created by following people.


## Core developers

- Sebastian Müller, GitHub: [@MuellerSeb](https://github.com/MuellerSeb), Email:  <sebastian@geostat-framework.org>
- Lennart Schüler, GitHub: [@LSchueler](https://github.com/LSchueler), Email:  <lennart@geostat-framework.org>


## Contributors (in order of contributions)

- Falk Heße, GitHub: [@fhesze](https://github.com/fhesze), Email: <falk.hesse@ufz.de>
- Bane Sullivan, GitHub: [@banesullivan](https://github.com/banesullivan)
- Tobias Glaubach, GitHub: [@TobiasGlaubach](https://github.com/TobiasGlaubach)
